# colorslogging
python3 logging custom


use with default

[![asciicast](https://asciinema.org/a/hTOS1zHr30larN3rVziEsOB21.svg)](https://asciinema.org/a/hTOS1zHr30larN3rVziEsOB21)

use with customized level & color


logger add new custom level

![usage](./pic/pic1.png "usage")
